Documentation
¶
Rendered for js/wasm
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Renderer ¶
type Renderer struct {
// contains filtered or unexported fields
}
func NewRenderer ¶
func (*Renderer) GetContainer ¶
GetContainer returns the container element
func (*Renderer) Patch ¶
Patch the DOM from old to new This is the main algorithm for the virtual DOM diffing Here remain most of the efficiciency for the virtual DOM TODO: Implement a better algorithm for keyed lists
func (*Renderer) RequestFrame ¶
func (r *Renderer) RequestFrame()
RequestFrame requests an animation frame for smooth rendering
Click to show internal directories.
Click to hide internal directories.